@@ -333,7 +333,8 @@ class Project:
                 )
             return None
 
-    def get_file_hash(self, session, link):
+    @staticmethod
+    def get_file_hash(session, link):
         h = hashlib.new(FAVORITE_HASH)
         err.print(f"Downloading file {link.filename} to obtain hash...")
         with open_file(link.url, session) as fp:
@@ -1095,12 +1096,10 @@ class Project:
 
     def remove_packages_from_pipfile(self, packages):
         parsed = self.parsed_pipfile
-        packages = set([pep423_name(pkg) for pkg in packages])
+        packages = {pep423_name(pkg) for pkg in packages}
         for category in self.get_package_categories():
             pipfile_section = parsed.get(category, {})
-            pipfile_packages = set(
-                [pep423_name(pkg_name) for pkg_name in pipfile_section.keys()]
-            )
+            pipfile_packages = {pep423_name(pkg_name) for pkg_name in pipfile_section}
             to_remove = packages & pipfile_packages
             for pkg in to_remove:
                 pkg_name = self.get_package_name_in_pipfile(pkg, category=category)
@@ -1128,7 +1127,7 @@ class Project:
         if extras:
             entry["extras"] = list(extras)
         if path_specifier:
-            entry["file"] = unquote(path_specifier)
+            entry["file"] = unquote(str(path_specifier))
         elif vcs_specifier:
             for vcs in VCS_LIST:
                 if vcs in package.link.scheme:
@@ -1147,6 +1146,10 @@ class Project:
                     vcs_parts = vcs_part.rsplit("@", 1)
                     entry["ref"] = vcs_parts[1].split("#", 1)[0].strip()
                     entry[vcs] = vcs_parts[0].strip()
+
+                    # Check and extract subdirectory fragment
+                    if package.link.subdirectory_fragment:
+                        entry["subdirectory"] = package.link.subdirectory_fragment
                     break
         else:
             entry["version"] = specifier
