@@ -11,7 +11,7 @@ from functools import lru_cache
 from pathlib import Path
 from tempfile import NamedTemporaryFile, TemporaryDirectory
 from typing import Any, AnyStr, Dict, List, Mapping, Optional, Sequence, Union
-from urllib.parse import urljoin, urlparse, urlsplit, urlunsplit
+from urllib.parse import urlparse, urlsplit, urlunsplit
 
 from pipenv.patched.pip._internal.models.link import Link
 from pipenv.patched.pip._internal.network.download import Downloader
@@ -246,6 +246,8 @@ def clean_resolved_dep(project, dep, is_top_level=False, current_entry=None):
             else:
                 lockfile[vcs_type] = dep[vcs_type]
             lockfile["ref"] = dep.get("ref")
+            if "subdirectory" in dep:
+                lockfile["subdirectory"] = dep["subdirectory"]
             is_vcs_or_file = True
 
     if "editable" in dep:
@@ -639,15 +641,12 @@ def find_package_name_from_directory(directory):
 def determine_path_specifier(package: InstallRequirement):
     if package.link:
         if package.link.scheme in ["http", "https"]:
-            path_specifier = package.link.url_without_fragment
-            return path_specifier
+            return package.link.url_without_fragment
         if package.link.scheme == "file":
             try:
-                path_specifier = os.path.relpath(package.link.file_path)
+                return Path(package.link.file_path).relative_to(Path.cwd()).as_posix()
             except ValueError:
-                # If os.path.relpath() fails, use the absolute path instead
-                path_specifier = os.path.abspath(package.link.file_path)
-            return path_specifier
+                return Path(package.link.file_path).as_posix()
 
 
 def determine_vcs_specifier(package: InstallRequirement):
@@ -900,13 +899,7 @@ def expansive_install_req_from_line(
     if expand_env:
         name = expand_env_variables(name)
 
-    if os.path.isfile(name) or os.path.isdir(name):
-        if not name.startswith("file:"):
-            # Make sure the path is absolute and properly formatted as a file: URL
-            absolute_path = os.path.abspath(name)
-            name = urljoin("file:", absolute_path)
-            name = "file:" + name
-
+    if editable or os.path.isdir(name):
         return install_req_from_editable(name, line_source)
 
     vcs_part = name
@@ -926,9 +919,7 @@ def expansive_install_req_from_line(
                 constraint=constraint,
                 user_supplied=user_supplied,
             )
-    if editable:
-        return install_req_from_editable(name, line_source)
-    if urlparse(name).scheme in ("http", "https", "file"):
+    if urlparse(name).scheme in ("http", "https", "file") or os.path.isfile(name):
         parts = parse_req_from_line(name, line_source)
     else:
         # It's a requirement
@@ -976,6 +967,9 @@ def install_req_from_pipfile(name, pipfile):
 
     if vcs:
         vcs_url = _pipfile[vcs]
+        subdirectory = _pipfile.get("subdirectory", "")
+        if subdirectory:
+            subdirectory = f"#subdirectory={subdirectory}"
         fallback_ref = ""
         if ("ssh://" in vcs_url and vcs_url.count("@") >= 2) or (
             "ssh://" not in vcs_url and "@" in vcs_url
@@ -988,13 +982,15 @@ def install_req_from_pipfile(name, pipfile):
         if not req_str.startswith(f"{vcs}+"):
             req_str = f"{vcs}+{req_str}"
         if f"{vcs}+file://" in req_str:
-            req_str = f"-e {req_str}#egg={name}{extras_str}"
+            req_str = (
+                f"-e {req_str}#egg={name}{extras_str}{subdirectory.replace('#', '&')}"
+            )
         else:
-            req_str = f"{name}{extras_str}@ {req_str}"
+            req_str = f"{name}{extras_str}@ {req_str}{subdirectory}"
     elif "path" in _pipfile:
-        req_str = f"{_pipfile['path']}{extras_str}"
+        req_str = str(Path(_pipfile["path"]).as_posix())
     elif "file" in _pipfile:
-        req_str = f"{_pipfile['file']}{extras_str}"
+        req_str = str(Path(_pipfile["file"]).as_posix())
     else:
         # We ensure version contains an operator. Default to equals (==)
         _pipfile["version"] = version = get_version(pipfile)
@@ -1054,7 +1050,7 @@ def get_constraints_from_deps(deps):
             else:
                 c = canonicalize_name(dep_name)
         else:
-            if not any([k in dep_version for k in ["path", "file", "uri"]]):
+            if not any(k in dep_version for k in ["path", "file", "uri"]):
                 if dep_version.get("skip_resolver") is True:
                     continue
                 version = dep_version.get("version", None)
@@ -1097,7 +1093,7 @@ def prepare_constraint_file(
         constraints_file.write(f"{requirementstxt_sources}\n")
 
     if constraints:
-        constraints_file.write("\n".join([c for c in constraints]))
+        constraints_file.write("\n".join(constraints))
     constraints_file.close()
     return constraints_file.name
 
