@@ -9,7 +9,7 @@ import subprocess
 import time
 import warnings
 from functools import partial
-from itertools import count, islice, tee
+from itertools import count, islice
 from typing import Any, Iterable
 
 DIRECTORY_CLEANUP_TIMEOUT = 1.0
@@ -62,19 +62,13 @@ def unnest(elem: Iterable) -> Any:
     """
 
     if isinstance(elem, Iterable) and not isinstance(elem, str):
-        elem, target = tee(elem, 2)
-    else:
-        target = elem
-    if not target or not _is_iterable(target):
-        yield target
-    else:
-        for el in target:
+        for el in elem:
             if isinstance(el, Iterable) and not isinstance(el, str):
-                el, el_copy = tee(el, 2)
-                for sub in unnest(el_copy):
-                    yield sub
+                yield from unnest(el)
             else:
                 yield el
+    else:
+        yield elem
 
 
 def dedup(iterable: Iterable) -> Iterable:
@@ -298,7 +292,7 @@ def set_write_bit(fn: str) -> None:
         for path in [fn, os.path.dirname(fn)]:
             try:
                 os.chflags(path, 0)
-            except AttributeError:
+            except AttributeError:  # noqa: PERF203
                 pass
         return None
     for root, dirs, files in os.walk(fn, topdown=False):
