@@ -65,6 +65,8 @@ def format_requirement_for_lockfile(
             entry[vcs] = original_deps[name]
         else:
             entry[vcs] = req.link.url
+        if pipfile_entry.get("subdirectory"):
+            entry["subdirectory"] = pipfile_entry["subdirectory"]
     if req.req:
         entry["version"] = str(req.specifier)
     elif version:
@@ -259,7 +261,7 @@ class Lockfile(BaseModel):
 
     @property
     def extended_keys(self):
-        return [k for k in itertools.product(self.section_keys, ["", "vcs", "editable"])]
+        return list(itertools.product(self.section_keys, ["", "vcs", "editable"]))
 
     def get(self, k):
         return self.__getitem__(k)
