@@ -266,7 +266,7 @@ class Resolver:
         pip_args.extend(["--cache-dir", self.project.s.PIPENV_CACHE_DIR])
         return pip_args
 
-    @property
+    @cached_property
     def pip_args(self):
         use_pep517 = environments.get_from_env("USE_PEP517", prefix="PIP")
         build_isolation = environments.get_from_env("BUILD_ISOLATION", prefix="PIP")
@@ -298,7 +298,7 @@ class Resolver:
         )
         return default_constraint_filename
 
-    @property
+    @cached_property
     def pip_options(self):
         pip_options, _ = self.pip_command.parser.parse_args(self.pip_args)
         pip_options.cache_dir = self.project.s.PIPENV_CACHE_DIR
@@ -377,10 +377,7 @@ class Resolver:
             )
             for c in self.parsed_default_constraints
         ]
-        default_constraints = []
-        for c in possible_default_constraints:
-            default_constraints.append(c)
-        return set(default_constraints)
+        return set(possible_default_constraints)
 
     @property
     def possible_constraints(self):
