@@ -49,11 +49,11 @@ def do_create_virtualenv(project, python=None, site_packages=None, pypi_mirror=N
         python = sys.executable
         using_string = "Using default python from"
     click.echo(
-        "{0} {1} {3} {2}".format(
+        "{} {} {} {}".format(
             click.style(using_string, bold=True),
             click.style(python, fg="yellow", bold=True),
-            click.style("to create virtualenv...", bold=True),
             click.style(f"({python_version(python)})", fg="green"),
+            click.style("to create virtualenv...", bold=True),
         ),
         err=True,
     )
@@ -217,7 +217,7 @@ def cleanup_virtualenv(project, bare=True):
 
 def ensure_python(project, python=None):
     # Runtime import is necessary due to the possibility that the environments module may have been reloaded.
-    if project.s.PIPENV_PYTHON and python is False:
+    if project.s.PIPENV_PYTHON and not python:
         python = project.s.PIPENV_PYTHON
 
     def abort(msg=""):
@@ -317,12 +317,6 @@ def ensure_python(project, python=None):
                             )
                             # Print the results, in a beautiful blue...
                             click.secho(c.stdout, fg="cyan", err=True)
-                            # Clear the pythonfinder caches
-                            from pipenv.vendor.pythonfinder import Finder
-
-                            finder = Finder(system=False, global_search=True)
-                            finder.find_python_version.cache_clear()
-                            finder.find_all_python_versions.cache_clear()
                     # Find the newly installed Python, hopefully.
                     version = str(version)
                     path_to_python = find_a_system_python(version)
@@ -431,7 +425,7 @@ def _inline_activate_virtualenv(project):
             raise exceptions.VirtualenvActivationException()
         with open(activate_this) as f:
             code = compile(f.read(), activate_this, "exec")
-            exec(code, dict(__file__=activate_this))
+            exec(code, {"__file__": activate_this})
     # Catch all errors, just in case.
     except Exception:
         click.echo(
